Público em Geral / Nota Fiscal Eletrônica / Consulta Completa da NFC-e

CONSULTA DA NFC-e
| PGL DISTRIBUICAO DE ALIMENTOS LTDA
CNPJ: 87.397.865/0022-46 Inscrição Estadual: 1090357130
RS 509 KM 07, 5941, CAMOBI, Santa Maria, RS
DANFE NFC-e - Documento Auxiliar da Nota Fiscal Eletrônica para Consumidor Final - Via Consumidor
NFC-e não permite aproveitamento de crédito de ICMS
Emissão normal
NFC-e nº: 36787 Série: 212 Data de Emissão: 08/10/2019 19:12:19
Consulte pela Chave de Acesso em https://www.sefaz.rs.gov.br/NFCE
CHAVE DE ACESSO
4319 1087 3978 6500 2246 6521 2000 0367 8710 0210 5674
Protocolo de Autorização: 143191383391722
CONSUMIDOR
CPF: 044.272.479-97
Código | Descrição | Qtde | Un | Vl Unit | Vl Total
2040 | FRUTI - BANANA PRATA KG | 1,03 | KG | 4,99 | 5,13
33030 | FRUTI - ABACAXI PEROLA UN | 1 | UN | 5,49 | 5,49
33030 | FRUTI - ABACAXI PEROLA UN | 1 | UN | 5,49 | 5,49
2060 | HORTI - BATATA DOCE ROSA KG | 2,09 | KG | 1,98 | 4,13
12540020 | ATUM SOLIDO COQUEIRO OLEO 170G | 1 | UN | 9,89 | 9,89
12540020 | ATUM SOLIDO COQUEIRO OLEO 170G | 1 | UN | 9,89 | 9,89
798020 | MILHO FUGINI SC 200G | 1 | UN | 2,39 | 2,39
5570 | FRUTI - MAMAOZINHO PAPAYA KG | 0,8 | KG | 2,78 | 2,22
661220 | AGUA MINERAL DA PEDRA SGAS 1.5L | 1 | UN | 2,99 | 2,99
524290 | PEITO PERU SEARA DEF ESCOL SAUD FAT KG | 0,204 | KG | 44,9 | 9,15
524390 | QUEIJO TIROLEZ MUSSARELA FAT KG | 0,58 | KG | 33,9 | 19,66
362480010 | MASSA INTEGRAL ORQUIDEA 500G. PARAFUSO | 1 | UN | 3,69 | 3,69
370180 | ERVA MATE SANTIAGO CHIMARRAO 1KG | 1 | UN | 11,98 | 11,98
128190 | MASSA ROMENA PIZZA PZ 150G | 1 | UN | 3,99 | 3,99
128190 | MASSA ROMENA PIZZA PZ 150G | 1 | UN | 3,99 | 3,99
128190 | MASSA ROMENA PIZZA PZ 150G | 1 | UN | 3,99 | 3,99
677960 | AGUA MINERAL VALLEVITA SG 8L | 2 | UN | 7,29 | 14,58
Valor total R$ | 118,65
Valor descontos R$ | 0,00
FORMA PAGAMENTO | VALOR PAGO R$
| NaN
Versão XSLT: 1.10

Administração Tributária: | Receita Estadual RS
Data/Hora da Consulta: | 11/08/2020 12:32:44